@@ -8,14 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_lambda_nodejs._jsii
-import aws_cdk.core._jsii
-import aws_cdk.custom_resources._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "p6-namer", "0.7.132", __name__[0:-6], "p6-namer@0.7.132.jsii.tgz"
+    "p6-namer", "0.7.182", __name__[0:-6], "p6-namer@0.7.182.jsii.tgz"
 )
 
 __all__ = [
